hotspot/test/compiler/intrinsics/bmi/TestBlsrL.java
changeset 40059 c2304140ed64
parent 36851 03e2f4d0a421
child 40631 ed82623d7831
--- a/hotspot/test/compiler/intrinsics/bmi/TestBlsrL.java	Tue Jul 12 08:42:46 2016 +0000
+++ b/hotspot/test/compiler/intrinsics/bmi/TestBlsrL.java	Tue Jul 12 18:24:48 2016 +0300
@@ -27,16 +27,20 @@
  * @bug 8031321
  * @summary Verify that results of computations are the same w/
  *          and w/o usage of BLSR instruction
- * @library /testlibrary /test/lib
+ * @library /testlibrary /test/lib /
  * @modules java.base/jdk.internal.misc
  *          java.management
  * @build TestBlsrL BMITestRunner Expr
  * @run main ClassFileInstaller sun.hotspot.WhiteBox
  *                              sun.hotspot.WhiteBox$WhiteBoxPermission
  * @run main/othervm -Xbootclasspath/a:. -XX:+UnlockDiagnosticVMOptions
- *                   -XX:+WhiteBoxAPI TestBlsrL
+ *                   -XX:+WhiteBoxAPI
+ *                   compiler.intrinsics.bmi.TestBlsrL
  */
 
+package compiler.intrinsics.bmi;
+
 import sun.hotspot.cpuinfo.CPUInfo;
 
 public class TestBlsrL {
@@ -27,16 +27,20 @@
  * @modules java.base/jdk.internal.misc
  *          java.management
- * @build TestBlsrL BMITestRunner Expr
- * @run main ClassFileInstaller sun.hotspot.WhiteBox
- *                              sun.hotspot.WhiteBox$WhiteBoxPermission
+ *
+ * @build compiler.intrinsics.bmi.TestBlsrL
+ * @run driver ClassFileInstaller sun.hotspot.WhiteBox
+ *                                sun.hotspot.WhiteBox$WhiteBoxPermission
  * @run main/othervm -Xbootclasspath/a:. -XX:+UnlockDiagnosticVMOptions